@@ -3,11 +3,11 @@ use 5.007;
 use strict;
 use warnings;
 
-use Carp qw(croak confess);
+use Carp qw(croak);
 use POSIX qw(strftime);
 use Time::HiRes qw(time);
 
-our $VERSION = '0.10_01';
+our $VERSION = '0.06';
 
 BEGIN {
 
@@ -36,20 +36,11 @@ BEGIN {
             *$_ = sub {
                 my ($self, $msg) = @_;
 
-                return if $self->level == -1;
-
                 $self->level($ENV{LS_LEVEL}) if defined $ENV{LS_LEVEL};
 
                 if ($sub =~ /^_(\d)$/){
-                    if (defined $self->_log_only){
-                        return if $1 != $self->_log_only;
-                    }
                     return if $1 > $self->level;
                 }
-                if (defined $self->_log_only){
-                    return if $self->_level_value($sub) != $self->_log_only;
-                }
-
                 return if $self->_level_value($sub) > $self->level;
 
                 my $proc = join '|', (caller(0))[1..2];
@@ -110,17 +101,7 @@ sub level {
     $self->{level} = $ENV{LS_LEVEL} if defined $ENV{LS_LEVEL};
     my $lvl;
 
-    if (defined $level && $level =~ /^-1$/){
-        $self->{level} = $level;
-    }
-    elsif (defined $level){
-
-        my $log_only;
-
-        if ($level =~ /^=/){
-            $level =~ s/=//;
-            $log_only = 1;
-        }
+    if (defined $level) {
         if ($level =~ /^\d$/ && defined $levels{$level}){
             $self->{level} = $level;
         }
@@ -131,15 +112,7 @@ sub level {
             CORE::warn
                 "invalid level $level specified, using default 'warning'/4\n";
         }
-
-        if ($log_only){
-            $self->_log_only($self->{level});
-        }
-        else {
-            $self->_log_only(-1);
-        }
     }
-
     return $self->{level};
 }
 sub file {
@@ -256,30 +229,9 @@ sub print {
 sub child {
     my ($self, $name) = @_;
     my $child = bless { %$self }, ref $self;
-    $name = $self->name . ".$name" if defined $self->name;
-    $child->name($name);
+    $child->name($self->name .".$name");
     return $child;
 }
-sub custom_display {
-    my ($self, $disp) = @_;
-
-    if (defined $disp) {
-        if ($disp =~ /^0$/) {
-            delete $self->{custom_display};
-            return 0;
-        }
-        else {
-            $self->{custom_display} = $disp;
-        }
-    }
-    return $self->{custom_display};
-}
-sub fatal {
-    my ($self, $msg) = @_;
-
-    $self->display(1);
-    confess("\n" . $self->_0("$msg"));
-}
 sub _level_value {
     my ($self, $level) = @_;
 
@@ -324,7 +276,6 @@ sub _generate_entry {
     $msg = $msg ? "$msg\n" : "\n";
 
     my $log_entry;
-    $log_entry .= $self->custom_display if defined $self->custom_display;
     $log_entry .= "[".$self->timestamp()."]" if $self->display('time');
     $log_entry .= "[$label]" if $self->display('label');
     $log_entry .= "[".$self->name."]" if $self->display('name') && $self->name;
@@ -342,27 +293,17 @@ sub _generate_entry {
         print $log_entry;
     }
 }
-sub _log_only {
-    my ($self, $level) = @_;
-    if (defined $level && $level == -1){
-        $self->{log_only} = undef;
-    }
-    else {
-        $self->{log_only} = $level if defined $level;
-    }
-    return $self->{log_only};
-}
 
 1;
 __END__
 
 =head1 NAME
 
-Logging::Simple - A simple but flexible logging mechanism.
+Logging::Simple - A simple but featureful logging mechanism.
 
 =for html
-<a href="http://travis-ci.org/stevieb9/p5-logging-simple"><img src="https://secure.travis-ci.org/stevieb9/p5-logging-simple.png"/>
-<a href='https://coveralls.io/github/stevieb9/p5-logging-simple?branch=master'><img src='https://coveralls.io/repos/stevieb9/p5-logging-simple/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
+<a href="http://travis-ci.org/stevieb9/p5-log-simple"><img src="https://secure.travis-ci.org/stevieb9/p5-log-simple.png"/>
+<a href='https://coveralls.io/github/stevieb9/p5-log-simple?branch=master'><img src='https://coveralls.io/repos/stevieb9/p5-log-simple/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
 
 =head1 SYNOPSIS
 
@@ -377,16 +318,8 @@ Logging::Simple - A simple but flexible logging mechanism.
     $log->_7("this is debug(). Default level is 4, so this won't print");
 
     $log->level(7);
-
     $log->debug("same as _7(). It'll print now");
 
-    $log->level('=3');
-    $log->_3("with a prepending '=' on level, we'll log this level ONLY");
-
-    $log->fatal("log a message along with confess() output, and terminate");
-
-    $log->level(-1); # disables all levels from doing anything
-
     $log->file('file.log');
     $log->info("this will go to file");
     $log->file(0); # back to STDOUT
@@ -408,7 +341,11 @@ Logging::Simple - A simple but flexible logging mechanism.
 
 =head1 DESCRIPTION
 
-Lightweight (core-only) and very simple yet flexible debug tool for printing or
+*** This is the first public release. The POD may be off a bit, and despite
+extensive CI testing on multiple platforms, there still may be a few small
+issues. ***
+
+Lightweight (core-only) and very simple yet powerful debug tool for printing or
 writing to file log type entries based on a configurable level (0-7).
 
 It provides the ability to programmatically change which output tags to display,
@@ -430,27 +367,18 @@ details.
 
 =head2 Levels
 
-Verbosity levels and associated named equivalents:
+Verbosity and associated levels are:
 
 =over 4
 
-=item   -1, disables all levels
-
-=item   0, 'emergency|emerg'
-
-=item   1, 'alert'
-
-=item   2, 'critical|crit'
-
-=item   3, 'error|err'
-
-=item   4, 'warning|warn'
-
-=item   5, 'notice'
-
-=item   6, 'info'
-
-=item   7, 'debug'
+=item level 0, 'emergency|emerg'
+=item level 1, 'alert'
+=item level 2, 'critical|crit'
+=item level 3, 'error|err'
+=item level 4, 'warning|warn'
+=item level 5, 'notice'
+=item level 6, 'info'
+=item level 7, 'debug'
 
 =back
 
@@ -459,7 +387,7 @@ have to remember the names at all. Using the numbers is often much easier.
 
 Setting the C<level> will display all messages related to that level and below.
 
-=head1 INITIALIZATION METHODS
+=head1 METHODS
 
 =head2 new(%args)
 
@@ -467,17 +395,50 @@ Builds and returns a new C<Logging::Simple> object. All arguments are optional,
 they can all be set using accessor methods after instantiation. These params
 are:
 
-    name        => $str  # optional, default is undef
-    level       => $num  # default 4, options, 0..7, -1 to disable all
-    file        => $str  # optional, default undef, send in a filename
-    write_mode  => $str  # defaults to append, other option is 'write'
-    print       => $bool # default on, enable/disable output and return instead
-    display     => $bool # default on, enable/disable log message tags
+=head3 name
 
-Each of the above parameters have associated methods described below with more
-details.
+Default: undef
 
-=head2 level($num)
+Specify a name for your log object. It will be displayed by default in the log
+output. The name of your program or module is a good choice.
+
+=head3 level => Integer
+
+Default: 4
+
+Specify the name or equivalent number (0-7) of the highest level to log. Note
+that this can be set in a C<LS_LEVEL> environment variable (and changed while
+your program is running).
+
+=head3 file => String
+
+Default: undef
+
+The name of a file to write log entries into. By default, we print to STDOUT.
+
+=head3 write_mode => Bool
+
+Default: 'a' (append)
+
+By default, we append to the chosen log file. Send in 'w' or 'write' to
+overwrite instead.
+
+=head3 print => Bool
+
+Default: 1 (enabled)
+
+If a false value is sent in (ie. 0), we'll disable printing the log entries,
+and return them as a string value instead on each call.
+
+=head3 display => Bool
+
+Default: enabled
+
+Send in a false value to disable all log entry tags, less the actual message.
+See C<display()> in L<METHODS> to learn how to enable and disable individual
+tags.
+
+=head2 level(Ingeger)
 
 Set and return the facility level. Will return the current value with a param
 sent in or not. It can be changed at any time. Note that you can set this with
@@ -490,35 +451,29 @@ By default, we write to STDOUT. Send in the name of a file to write there
 instead. Mode is optional; we'll append to the file by default. Send in 'w' or
 'write' to overwrite the file.
 
-=head2 display(%hash|$bool)
+=head2 display(HASH|Bool)
 
 List of log entry tags, and default printing status:
-
-    name  => 1, # specified in new() or name()
-    time  => 1, # timestamp
+    name  => 1, #specified in new() or name()
+    time  => 1,
     label => 1, # the string value of the level being called
     pid   => 0, # process ID
     proc  => 0, # "filename|line number" of the caller
 
-In hash param mode, send in any or all of the tags with 1 (enable) or 0
+In HASH param mode, send in any or all of the tags with 1 (enable) or 0
 (disable).
 
 You can also send in 1 to enable all of the tags, or 0 to disable them all.
 
-=head2 custom_display($str|$false)
-
-This will create a custom tag in your output, and place it at the first column
-of the output. Send in 0 (false) to disable/clear it.
-
-=head2 print($bool)
+=head2 print(Bool)
 
 Default is enabled. If disabled, we won't print at all, and instead, return the
 log entry as a scalar string value.
 
-=head2 child($name)
+=head2 child('name')
 
-This method will create a clone of the existing C<Logging::Simple> object, and
-then concatenate the parent's name with the optional name sent in here for easy
+This method will create a clone of the existing C<Logging::Simple> object, and then
+concatenate the parent's name with the optional name sent in here for easy
 identification in the logs.
 
 All settings employed by the parent will be used in the child, unless explicity
@@ -531,59 +486,54 @@ from there.
 
 =head1 LOGGING METHODS
 
-=head2 emergency($msg)
+=head2 emergency
 
 Level 0
 
 aka: C<_0()>, C<emerg()>
 
-=head2 alert($msg)
+=head2 alert
 
 Level 1
 
 aka: C<_1()>
 
-=head2 critical($msg)
+=head2 critical
 
 Level 2
 
 aka: C<_2()>, C<crit()>
 
-=head2 error($msg)
+=head2 error
 
 Level 3
 
 aka: C<_3()>, C<err()>
 
-=head2 warning($msg)
+=head2 warning
 
 Level 4
 
 aka: C<_4()>, C<warn()>
 
-=head2 notice($msg)
+=head2 notice
 
 Level 5
 
 aka: C<_5()>
 
-=head2 info($msg)
+=head2 info
 
 Level 6
 
 aka: C<_6()>
 
-=head2 debug($msg)
+=head2 debug
 
 Level 7
 
 aka: C<_7()>
 
-=head2 fatal($msg)
-
-Log the message, along with the trace C<confess()> produces, and die
-immediately.
-
 =head1 HELPER METHODS
 
 These methods may be handy to the end user, but aren't required for end-use.
@@ -597,7 +547,8 @@ names, in numeric order from lowest to highest.
 
 =head2 timestamp
 
-Returns the current time in the following format: C<2016-03-17 17:51:02.241>
+Returns the current time in the following format: C<2016-03-17 17:51:02.241
+>
 
 =head1 AUTHOR
 
@@ -606,11 +557,11 @@ Steve Bertrand, C<< <steveb at cpan.org> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to
-L<https://github.com/stevieb9/p5-logging-simple/issues>
+L<https://github.com/stevieb9/p5-log-simple/issues>
 
 =head1 REPOSITORY
 
-L<https://github.com/stevieb9/p5-logging-simple>
+L<https://github.com/stevieb9/p5-log-simple>
 
 =head1 BUILD RESULTS (THIS VERSION)
 
